@@ -32,14 +32,11 @@ __author__ = 'Matt Wise <matt@nextdoor.com>'
 
 class Sleep(base.BaseActor):
 
-    """Simple actor that just sleeps for an arbitrary amount of time.
+    """Simple actor that just sleeps for an arbitrary amount of time."""
 
-    Args:
-        options: Dictionary with the following settings:
-          { 'sleep': <int of time to sleep> }
-    """
-
-    required_options = ['sleep']
+    all_options = {
+        'sleep': ((int, float), None, 'Number of seconds to do nothing.')
+    }
 
     @gen.coroutine
     def _execute(self):
@@ -47,8 +44,8 @@ class Sleep(base.BaseActor):
 
         raises: gen.Return(True)
         """
-        self.log.debug('Sleeping for %s seconds' % self._options['sleep'])
+        self.log.debug('Sleeping for %s seconds' % self.option('sleep'))
         if not self._dry:
-            yield utils.tornado_sleep(seconds=self._options['sleep'])
+            yield utils.tornado_sleep(seconds=self.option('sleep'))
 
         raise gen.Return(True)
